==> huaweicloudsdkcae-3.1.138-py2.py3-none-any.whl: huaweicloudsdkcae/v1/model/agency_metadata.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AgencyMetadata:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'enum': 'object'
    }

    attribute_map = {
        'name': 'name',
        'enum': 'enum'
    }

    def __init__(self, name=None, enum=None):
        """AgencyMetadata

        The model defined in huaweicloud sdk

        :param name: 委托名称，固定值“cae_trust”，该值不可修改。
        :type name: str
        :param enum: 
        :type enum: object
        """
        
        

        self._name = None
        self._enum = None
        self.discriminator = None

        self.name = name
        if enum is not None:
            self.enum = enum

    @property
    def name(self):
        """Gets the name of this AgencyMetadata.

        委托名称，固定值“cae_trust”，该值不可修改。

        :return: The name of this AgencyMetadata.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AgencyMetadata.

        委托名称，固定值“cae_trust”，该值不可修改。

        :param name: The name of this AgencyMetadata.
        :type name: str
        """
        self._name = name

    @property
    def enum(self):
        """Gets the enum of this AgencyMetadata.

        :return: The enum of this AgencyMetadata.
        :rtype: object
        """
        return self._enum

    @enum.setter
    def enum(self, enum):
        """Sets the enum of this AgencyMetadata.

        :param enum: The enum of this AgencyMetadata.
        :type enum: object
        """
        self._enum = enum

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgencyMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcae-3.1.144-py2.py3-none-any.whl: huaweicloudsdkcae/v1/model/agency_metadata.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AgencyMetadata:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'enum': 'object'
    }

    attribute_map = {
        'name': 'name',
        'enum': 'enum'
    }

    def __init__(self, name=None, enum=None):
        r"""AgencyMetadata

        The model defined in huaweicloud sdk

        :param name: 委托名称，固定值“cae_trust”，该值不可修改。
        :type name: str
        :param enum: 
        :type enum: object
        """
        
        

        self._name = None
        self._enum = None
        self.discriminator = None

        self.name = name
        if enum is not None:
            self.enum = enum

    @property
    def name(self):
        r"""Gets the name of this AgencyMetadata.

        委托名称，固定值“cae_trust”，该值不可修改。

        :return: The name of this AgencyMetadata.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this AgencyMetadata.

        委托名称，固定值“cae_trust”，该值不可修改。

        :param name: The name of this AgencyMetadata.
        :type name: str
        """
        self._name = name

    @property
    def enum(self):
        r"""Gets the enum of this AgencyMetadata.

        :return: The enum of this AgencyMetadata.
        :rtype: object
        """
        return self._enum

    @enum.setter
    def enum(self, enum):
        r"""Sets the enum of this AgencyMetadata.

        :param enum: The enum of this AgencyMetadata.
        :type enum: object
        """
        self._enum = enum

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgencyMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
